# This file was auto-generated by Fern from our API Definition.

import typing

from .click_action_data_metadata import ClickActionDataMetadata

ClickActionData = typing.Union[ClickActionDataMetadata, typing.Literal["clicked"]]
