# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import dlc, rcs, toll_free
    from .dlc import (
        UpsertDlcCampaignHelpKeywords,
        UpsertDlcCampaignKeywords,
        UpsertDlcCampaignLinks,
        UpsertDlcCampaignOptInKeywords,
        UpsertDlcCampaignOptOutKeywords,
        UpsertDlcCampaignOptions,
        UpsertDlcCampaignUseCase,
    )
    from .rcs import (
        RcsAgentEmail,
        RcsAgentPhone,
        RcsAgentWebsite,
        RcsAutofillResponse,
        UpsertRcsAgent,
        UpsertRcsLinks,
        UpsertRcsOptIn,
        UpsertRcsOptOut,
        UpsertRcsUseCase,
    )
    from .toll_free import TollFreeAutofillResponse, UpsertTollFreeSchemaOptIn, UpsertTollFreeSchemaUseCase
_dynamic_imports: typing.Dict[str, str] = {
    "RcsAgentEmail": ".rcs",
    "RcsAgentPhone": ".rcs",
    "RcsAgentWebsite": ".rcs",
    "RcsAutofillResponse": ".rcs",
    "TollFreeAutofillResponse": ".toll_free",
    "UpsertDlcCampaignHelpKeywords": ".dlc",
    "UpsertDlcCampaignKeywords": ".dlc",
    "UpsertDlcCampaignLinks": ".dlc",
    "UpsertDlcCampaignOptInKeywords": ".dlc",
    "UpsertDlcCampaignOptOutKeywords": ".dlc",
    "UpsertDlcCampaignOptions": ".dlc",
    "UpsertDlcCampaignUseCase": ".dlc",
    "UpsertRcsAgent": ".rcs",
    "UpsertRcsLinks": ".rcs",
    "UpsertRcsOptIn": ".rcs",
    "UpsertRcsOptOut": ".rcs",
    "UpsertRcsUseCase": ".rcs",
    "UpsertTollFreeSchemaOptIn": ".toll_free",
    "UpsertTollFreeSchemaUseCase": ".toll_free",
    "dlc": ".",
    "rcs": ".",
    "toll_free": ".",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "RcsAgentEmail",
    "RcsAgentPhone",
    "RcsAgentWebsite",
    "RcsAutofillResponse",
    "TollFreeAutofillResponse",
    "UpsertDlcCampaignHelpKeywords",
    "UpsertDlcCampaignKeywords",
    "UpsertDlcCampaignLinks",
    "UpsertDlcCampaignOptInKeywords",
    "UpsertDlcCampaignOptOutKeywords",
    "UpsertDlcCampaignOptions",
    "UpsertDlcCampaignUseCase",
    "UpsertRcsAgent",
    "UpsertRcsLinks",
    "UpsertRcsOptIn",
    "UpsertRcsOptOut",
    "UpsertRcsUseCase",
    "UpsertTollFreeSchemaOptIn",
    "UpsertTollFreeSchemaUseCase",
    "dlc",
    "rcs",
    "toll_free",
]
