# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.scheduled_messaage import ScheduledMessaage
from ....types.sent_rcs_details import SentRcsDetails

RcsSendResponse = typing.Union[SentRcsDetails, ScheduledMessaage]
