# This file was auto-generated by Fern from our API Definition.

import typing

RcsCampaignOptInMethodEnum = typing.Union[
    typing.Literal["WEBSITE", "SMS", "APP", "VERBAL", "WRITTEN", "OTHER"], typing.Any
]
