# This file was auto-generated by Fern from our API Definition.

import typing

from .click_action import ClickAction
from .location_share_action import LocationShareAction

InboundButton = typing.Union[ClickAction, LocationShareAction]
