# This file was auto-generated by Fern from our API Definition.

import typing

from .rcs_cards import RcsCards
from .rcs_text_content import RcsTextContent
from .rcs_validate_content_media import RcsValidateContentMedia

RcsValidateContent = typing.Union[RcsTextContent, RcsValidateContentMedia, RcsCards]
