# This file was auto-generated by Fern from our API Definition.

import typing

from .rcs_cards_content import RcsCardsContent
from .rcs_media_content import RcsMediaContent
from .rcs_text_content import RcsTextContent

RcsContent = typing.Union[RcsTextContent, RcsMediaContent, RcsCardsContent]
